Basis expansions from a definition of a smoother using the syntax of mgcv's
smooths via mgcv::s()., mgcv::te(), mgcv::ti(), and mgcv::t2(), or
directly from a fitted GAM(M).
Usage
basis(object, ...)
# S3 method for class 'gam'
basis(
object,
select = NULL,
term = deprecated(),
data = NULL,
n = 100,
n_2d = 50,
n_3d = 16,
n_4d = 4,
partial_match = FALSE,
envir = NULL,
...
)
# S3 method for class 'scam'
basis(
object,
select = NULL,
term = deprecated(),
data = NULL,
n = 100,
n_2d = 50,
n_3d = 16,
n_4d = 4,
partial_match = FALSE,
...
)
# S3 method for class 'gamm'
basis(
object,
select = NULL,
term = deprecated(),
data = NULL,
n = 100,
n_2d = 50,
n_3d = 16,
n_4d = 4,
partial_match = FALSE,
...
)
# S3 method for class 'gamm4'
basis(
object,
select = NULL,
term = deprecated(),
data = NULL,
n = 100,
n_2d = 50,
n_3d = 16,
n_4d = 4,
partial_match = FALSE,
...
)
# Default S3 method
basis(
object,
data,
knots = NULL,
constraints = FALSE,
at = NULL,
diagonalize = FALSE,
coefficients = NULL,
envir = NULL,
...
)Arguments
- object
a smooth specification, the result of a call to one of
mgcv::s().,mgcv::te(),mgcv::ti(), ormgcv::t2(), or a fitted GAM(M) model.- ...
other arguments passed to
mgcv::smoothCon().- select
character; select smooths in a fitted model
- term
- data
a data frame containing the variables used in
smooth.- n
numeric; the number of points over the range of the covariate at which to evaluate a univariate smooth.
- n_2d
numeric; the number of points along each of the first two axes of a smooth surface, including surface panels of higher-dimensional smooths. The default is 50 in plotting and plot-preparation functions. If
NULL, useninstead. Ignored when evaluationdataare supplied. Factor levels are retained, and curves with only one continuous covariate usen.- n_3d
numeric; the number of new observations to generate for the third dimension of a 3D smooth.
- n_4d
numeric; the number of new observations to generate for the dimensions higher than 2 (!) of a kD smooth (k >= 4). For example, if the smooth is a 4D smooth, each of dimensions 3 and 4 will get
n_4dnew observations.- partial_match
logical; in the case of character
select, shouldselectmatch partially againstsmooths? Ifpartial_match = TRUE,selectmust only be a single string, a character vector of length 1.- envir
an optional environment supplying functions and constants used in model expressions. The available model formula environment is used when
NULL. Covariate observations should be supplied indata.- knots
a list or data frame with named components containing knots locations. Names must match the covariates for which the basis is required. See
mgcv::smoothCon().- constraints
logical; should identifiability constraints be applied to the smooth basis. See argument
absorb.consinmgcv::smoothCon().- at
a data frame containing values of the smooth covariate(s) at which the basis should be evaluated.
- diagonalize
logical; if
TRUE, reparameterises the smooth such that the associated penalty is an identity matrix. This has the effect of turning the last diagonal elements of the penalty to zero, which highlights the penalty null space.- coefficients
numeric; vector of values for the coefficients of the basis functions.