get_by_smooth: Extract an factor-by smooth by name

get_by_smoothR Documentation

Extract an factor-by smooth by name

Description

Extract an factor-by smooth by name

Usage

get_by_smooth(object, term, level)

Arguments

object

a fitted GAM model object.

term

character; the name of a smooth term to extract.

level

character; which level of the factor to extract the smooth for.

Value

A single smooth object, or a list of smooths if several match the named term.


gratia documentation built on Feb. 7, 2026, 9:06 a.m.