load_mgcv: Load mgcv quietly

load_mgcvR Documentation

Load mgcv quietly

Description

Simple function that loads the mgcv package whilst suppressing the startup messages that it prints to the console.

Usage

load_mgcv()

Value

Returns a logical vectors invisibly, indicating whether the package was loaded or not.


gratia documentation built on Feb. 7, 2026, 9:06 a.m.