| residuals_hist_plot | R Documentation |
Histogram of model residuals
residuals_hist_plot(
model,
type = c("deviance", "pearson", "response", "pit", "quantile"),
n_bins = c("sturges", "scott", "fd"),
ylab = NULL,
xlab = NULL,
title = NULL,
subtitle = NULL,
caption = NULL,
seed = NULL
)
model |
a fitted model. Currently only class |
type |
character; type of residuals to use. One of |
n_bins |
character or numeric; either the number of bins or a string indicating how to calculate the number of bins. |
ylab |
character or expression; the label for the y axis. If not supplied, a suitable label will be generated. |
xlab |
character or expression; the label for the y axis. If not supplied, a suitable label will be generated. |
title |
character or expression; the title for the plot. See
|
subtitle |
character or expression; the subtitle for the plot. See
|
caption |
character or expression; the plot caption. See
|
seed |
integer; random seed to use for PIT or quantile residuals. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.