Add residuals from a model to a data frame
Arguments
- data
a data frame containing values for the variables used to fit the model, in fitting order. Supply either the retained fitting rows or, for
na.exclude, the original fitting rows after anysubset. This does not compute residuals for new or reordered observations.- model
a fitted model for which a
stats::residuals()method is available. S3 method dispatch is performed on themodelargument.- value
character; the name of the variable in which model residuals will be stored.
- ...
additional arguments passed to methods.